@@ -15,7 +15,7 @@
 #' @export
 get_release_logs <- function(gitstats,
                              since = NULL,
-                             until = Sys.Date() + lubridate::days(1),
+                             until = Sys.Date(),
                              cache = TRUE,
                              verbose = FALSE,
                              progress = TRUE) {
